"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateServerlessConfig = exports.writeServerlessConfig = exports.getServerlessConfig = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
//Load the serverless config for a package
function getServerlessConfig(path = process.cwd()) {
    //Get from each type of file
    let out = {};
    if (fs_1.existsSync(path_1.join(path, "package.json"))) {
        const { name, version, serverless } = JSON.parse(fs_1.readFileSync(path_1.join(path, "package.json"), { encoding: "utf-8" }));
        out.name = name;
        out.version = version;
        if (serverless)
            out = { ...out, ...serverless };
    }
    if (fs_1.existsSync(path_1.join(path, "serverless.config.js"))) {
        const result = require(path_1.join(path, "serverless.config.js"));
        if (result)
            out = { ...out, ...result };
    }
    if (fs_1.existsSync(path_1.join(path, ".serverlessrc"))) {
        const result = JSON.parse(fs_1.readFileSync(path_1.join(path, ".serverlessrc"), { encoding: "utf-8" }));
        if (result)
            out = { ...out, ...result };
    }
    return out;
}
exports.getServerlessConfig = getServerlessConfig;
function writeServerlessConfig(newConfigMap, path = process.cwd(), targetFile = ".serverlessrc") {
    switch (targetFile) {
        case "package.json": {
            let p = JSON.parse(fs_1.readFileSync(path_1.join(path, "package.json"), { encoding: "utf-8" }));
            p.serverless = newConfigMap;
            fs_1.writeFileSync(path_1.join(path, "package.json"), JSON.stringify(p, null, 2));
        }
        case ".serverlessrc":
            const json = JSON.stringify(newConfigMap);
            fs_1.writeFileSync(path_1.join(path, ".serverlessrc"), json);
            break;
        default:
            throw new Error("Not a valid target for writing");
    }
}
exports.writeServerlessConfig = writeServerlessConfig;
function updateServerlessConfig(configUpdates, path = process.cwd(), targetFile = ".serverlessrc") {
    switch (targetFile) {
        case "package.json": {
            let p = JSON.parse(fs_1.readFileSync(path_1.join(path, "package.json"), { encoding: "utf-8" }));
            if (!p.serverless)
                p.serverless = configUpdates;
            else
                p.serverless = { ...p.serverless, ...configUpdates };
            fs_1.writeFileSync(path_1.join(path, "package.json"), JSON.stringify(p, null, 2));
        }
        case ".serverlessrc":
            if (!fs_1.existsSync(path_1.join(path, ".serverlessrc")))
                return writeServerlessConfig(configUpdates, path, targetFile);
            let s = JSON.parse(fs_1.readFileSync(path_1.join(path, ".serverlessrc"), { encoding: "utf-8" }));
            s = { ...s, ...configUpdates };
            const json = JSON.stringify(s, null, 2);
            fs_1.writeFileSync(path_1.join(path, ".serverlessrc"), json);
            break;
        default:
            throw new Error("Not a valid target for writing");
    }
}
exports.updateServerlessConfig = updateServerlessConfig;
//# sourceMappingURL=index.js.map